@@ -16,7 +16,7 @@
 #include <sys/types.h>
 
 /* oracle_fdw version */
-#define ORACLE_FDW_VERSION "2.6.0"
+#define ORACLE_FDW_VERSION "2.7.0"
 
 /* definitions that need OCI */
 #ifdef OCI_ORACLE
@@ -30,7 +30,7 @@ struct connEntry
 	OCISvcCtx *svchp;
 	OCISession *userhp;
 	OCIType *geomtype;
-	struct handleEntry *handlelist;
+	struct stmtHandleEntry *stmtlist;
 	int xact_level;  /* 0 = none, 1 = main, else subtransaction */
 	struct connEntry *next;
 };
@@ -223,7 +223,7 @@ extern void oracleGetLob(oracleSession *session, void *locptr, oraType type, cha
 extern void oracleClientVersion(int *major, int *minor, int *update, int *patch, int *port_patch);
 extern void oracleServerVersion(oracleSession *session, int *major, int *minor, int *update, int *patch, int *port_patch);
 extern void *oracleGetGeometryType(oracleSession *session);
-extern int oracleGetImportColumn(oracleSession *session, char *dblink, char *schema, char **tabname, char **colname, oraType *type, int *charlen, int *typeprec, int *typescale, int *nullable, int *key);
+extern int oracleGetImportColumn(oracleSession *session, char *dblink, char *schema, char *limit_to, char **tabname, char **colname, oraType *type, int *charlen, int *typeprec, int *typescale, int *nullable, int *key, int skip_tables, int skip_views, int skip_matviews);
 
 /*
  * functions defined in oracle_fdw.c
