@@ -12,7 +12,15 @@ CREATE SERVER oracle FOREIGN DATA WRAPPER oracle_fdw OPTIONS (dbserver '', isola
 
 CREATE USER MAPPING FOR CURRENT_ROLE SERVER oracle OPTIONS (user 'SCOTT', password 'tiger');
 
--- drop the Oracle tables if they exist
+-- drop the Oracle objects if they exist
+DO
+$$BEGIN
+   SELECT oracle_execute('oracle', 'DROP VIEW scott.ttv');
+EXCEPTION
+   WHEN OTHERS THEN
+      NULL;
+END;$$;
+
 DO
 $$BEGIN
    SELECT oracle_execute('oracle', 'DROP TABLE scott.typetest1 PURGE');
@@ -21,6 +29,14 @@ EXCEPTION
       NULL;
 END;$$;
 
+DO
+$$BEGIN
+   SELECT oracle_execute('oracle', 'DROP MATERIALIZED VIEW scott.mattest2');
+EXCEPTION
+   WHEN OTHERS THEN
+      NULL;
+END;$$;
+
 DO
 $$BEGIN
    SELECT oracle_execute('oracle', 'DROP TABLE scott.typetest2 PURGE');
@@ -62,6 +78,12 @@ SELECT oracle_execute(
           ') SEGMENT CREATION IMMEDIATE'
        );
 
+SELECT oracle_execute(
+          'oracle',
+          E'CREATE VIEW scott.ttv AS\n'
+          'SELECT id, vc FROM scott.typetest1'
+       );
+
 SELECT oracle_execute(
           'oracle',
           E'CREATE TABLE scott.typetest2 (\n'
@@ -114,6 +136,13 @@ SELECT oracle_execute(
           ')'
        );
 
+-- a materialized view
+SELECT oracle_execute(
+          'oracle',
+          E'CREATE MATERIALIZED VIEW scott.mattest2 REFRESH COMPLETE AS\n'
+          '   SELECT id, ts1, ts2, ts3 FROM scott.typetest2'
+       );
+
 -- create the foreign tables
 CREATE FOREIGN TABLE typetest1 (
    id  integer OPTIONS (key 'yes') NOT NULL,
@@ -256,6 +285,12 @@ INSERT INTO typetest1 (id, c, nc, vc, nvc, lc, r, u, lb, lr, b, num, fl, db, d,
    '3 years'
 );
 
+-- try inserting an empty string into a CLOB (will become NULL)
+BEGIN;
+INSERT INTO typetest1 (id, lc) VALUES (5, '');
+SELECT lc IS NULL FROM typetest1 WHERE id = 5;
+ROLLBACK;
+
 /*
  * Test SELECT, UPDATE ... RETURNING, DELETE and transactions.
  */
@@ -343,15 +378,15 @@ EXPLAIN (COSTS off) SELECT typetest1 FROM typetest1;
  * Test parameters.
  */
 
-PREPARE stmt(integer, date, timestamp) AS SELECT d FROM typetest1 WHERE id = $1 AND d < $2 AND ts < $3;
+PREPARE stmt(integer, date, timestamp, uuid) AS SELECT d FROM typetest1 WHERE id = $1 AND d < $2 AND ts < $3 AND u = $4;
 -- six executions to switch to generic plan
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXPLAIN (COSTS off) EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
-EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXPLAIN (COSTS off) EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
+EXECUTE stmt(1, '2011-03-09', '2011-03-09 05:00:00', '055e26fa-f1d8-771f-e053-1645990add93');
 DEALLOCATE stmt;
 -- test NULL parameters
 SELECT id FROM typetest1 WHERE vc = (SELECT NULL::text);
@@ -519,16 +554,15 @@ DEALLOCATE stmt;
  * Test push-down of the LIMIT clause.
  */
 
--- the LIMIT clause is pushed down with and without ORDER BY
+-- the LIMIT clause is only pushed down with ORDER BY
 EXPLAIN (COSTS off) SELECT d FROM typetest1 LIMIT 2;
-SELECT d FROM typetest1 LIMIT 2;
 EXPLAIN (COSTS off) SELECT d FROM typetest1 ORDER BY d LIMIT 2;
 SELECT d FROM typetest1 ORDER BY d LIMIT 2;
 -- the LIMIT clause is not pushed down because the ORDER BY is not
 EXPLAIN (COSTS off) SELECT d FROM typetest1 ORDER BY lc LIMIT 2;
 -- with an OFFSET clause, the offset value is added to the limit
-EXPLAIN (COSTS off) SELECT * FROM qtest LIMIT 1 OFFSET 2;
-SELECT * FROM qtest LIMIT 1 OFFSET 2;
+EXPLAIN (COSTS off) SELECT * FROM qtest ORDER BY id LIMIT 1 OFFSET 2;
+SELECT * FROM qtest ORDER BY id LIMIT 1 OFFSET 2;
 -- no LIMIT push-down if there is a GROUP BY clause
 EXPLAIN (COSTS off) SELECT d, count(*) FROM typetest1 GROUP BY d LIMIT 2;
 SELECT d, count(*) FROM typetest1 GROUP BY d LIMIT 2;
